@@ -688,7 +688,7 @@ libpcap_read_packet(wtap *wth, FILE_T fh, struct wtap_pkthdr *phdr,
 	}
 
 	phdr_len = pcap_process_pseudo_header(fh, wth->file_type_subtype,
-	    wth->file_encap, packet_size, TRUE, phdr, err, err_info);
+	    wth->file_encap, packet_size, phdr, err, err_info);
 	if (phdr_len < 0)
 		return FALSE;	/* error */
 
